import AppSearchAPIConnector from "@elastic/search-ui-app-search-connector";
import React from "react";
import {appConfig} from './env_setup';
import {
  ErrorBoundary,
  Facet,
  SearchProvider,
  SearchBox,
  Results,
  PagingInfo,
  ResultsPerPage,
  Paging,
  Sorting,
  WithSearch
} from "@elastic/react-search-ui";
import {
  BooleanFacet,
  Layout,
  SingleLinksFacet,
  SingleSelectFacet
} from "@elastic/react-search-ui-views";
import "@elastic/react-search-ui-views/lib/styles/styles.css";
import { SearchDriverOptions } from "@elastic/search-ui";

// const appConfig = {
//     "engineName": "testlocalengine",
//     "endpointBase": "https://dev-eps.foundationservices.crohnscolitisfoundation.org",
//     "searchKey": "search-zh61j1dr67dj3p9a7fqks9n7",
//     "resultFields": {
//         "body": {
//             "raw": {}
//         },
//         "changed": {
//             "raw": {}
//         },
//         "created": {
//             "raw": {}
//         },
//         "default_langcode": {
//             "raw": {}
//         },
//         "langcode": {
//             "raw": {}
//         },
//         "menu_link": {
//             "raw": {}
//         },
//         "nid": {
//             "raw": {}
//         },
//         "path": {
//             "raw": {}
//         },
//         "promote": {
//             "raw": {}
//         },
//         "revision_default": {
//             "raw": {}
//         },
//         "revision_log": {
//             "raw": {}
//         },
//         "revision_timestamp": {
//             "raw": {}
//         },
//         "revision_translation_affected": {
//             "raw": {}
//         },
//         "revision_uid": {
//             "raw": {}
//         },
//         "status": {
//             "raw": {}
//         },
//         "sticky": {
//             "raw": {}
//         },
//         "title": {
//             "raw": {}
//         },
//         "type": {
//             "raw": {}
//         },
//         "uid": {
//             "raw": {}
//         }
//     },
//     "sortFields": [
//         {
//             "title": "Content type",
//             "field": "type"
//         }
//     ],
//     "facets": {
//         "nid": {
//             "type": "value"
//         },
//         "body": {
//             "type": "value"
//         },
//         "revision_translation_affected": {
//             "type": "value"
//         },
//         "title": {
//             "type": "value"
//         },
//         "type": {
//             "type": "value"
//         },
//         "revision_uid": {
//             "type": "value"
//         },
//         "langcode": {
//             "type": "value"
//         },
//         "path": {
//             "type": "value"
//         },
//         "promote": {
//             "type": "value"
//         },
//         "uid": {
//             "type": "value"
//         },
//         "revision_timestamp": {
//             "type": "value"
//         },
//         "revision_log": {
//             "type": "value"
//         },
//         "menu_link": {
//             "type": "value"
//         },
//         "revision_default": {
//             "type": "value"
//         },
//         "created": {
//             "type": "value"
//         },
//         "default_langcode": {
//             "type": "value"
//         },
//         "sticky": {
//             "type": "value"
//         },
//         "changed": {
//             "type": "value"
//         },
//         "status": {
//             "type": "value"
//         }
//     },
//     "disjunctive": [
//         "type",
//         "nid",
//         "body",
//         "revision_translation_affected",
//         "title",
//         "revision_uid",
//         "langcode",
//         "path",
//         "promote",
//         "uid",
//         "revision_timestamp",
//         "revision_log",
//         "menu_link",
//         "revision_default",
//         "created",
//         "default_langcode",
//         "sticky",
//         "changed",
//         "status"
//     ],
//     "titleField": "title",
//     "urlField": "title",
//     "_ctags": [
//         "config:appsearch.appsearch_searchui.global_search_ui"
//     ],
//     "searchables": {
//         "type": "type",
//         "nid": 0,
//         "body": 0,
//         "revision_translation_affected": 0,
//         "title": 0,
//         "revision_uid": 0,
//         "langcode": 0,
//         "path": 0,
//         "promote": 0,
//         "uid": 0,
//         "revision_timestamp": 0,
//         "revision_log": 0,
//         "menu_link": 0,
//         "revision_default": 0,
//         "created": 0,
//         "default_langcode": 0,
//         "sticky": 0,
//         "changed": 0,
//         "status": 0
//     }
// };

const connector = new AppSearchAPIConnector({
  searchKey: appConfig?.searchKey,
  engineName: appConfig?.engineName,
  endpointBase: appConfig?.endpointBase,
});

const config: SearchDriverOptions = {
  alwaysSearchOnInitialLoad: true,
  apiConnector: connector,
  hasA11yNotifications: true,
  // searchQuery: {
  //   result_fields: {
  //     title: { raw: {} },
  //     body: {
  //       snippet: {
  //         fallback: true
  //       }
  //     }
  //   },
  //   search_fields: {
  //     title: {},
  //     id: {}
  //   },
  //   disjunctiveFacets: [""],
  //   facets: {}
  // }
  searchQuery: {
    result_fields: appConfig?.resultFields,
    // result_fields: {
    //   visitors: { raw: {} },
    //   world_heritage_site: { raw: {} },
    //   location: { raw: {} },
    //   acres: { raw: {} },
    //   square_km: { raw: {} },
    //   title: {
    //     snippet: {
    //       size: 100,
    //       fallback: true
    //     }
    //   },
    //   nps_link: { raw: {} },
    //   states: { raw: {} },
    //   date_established: { raw: {} },
    //   image_url: { raw: {} },
    //   description: {
    //     snippet: {
    //       size: 100,
    //       fallback: true
    //     }
    //   }
    // },
    disjunctiveFacets: appConfig?.disjunctive,
    facets: appConfig?.facets,
    // facets: {
    //   world_heritage_site: { type: "value" },
    //   states: { type: "value", size: 30 },
    //   acres: {
    //     type: "range",
    //     ranges: [
    //       { from: -1, name: "Any" },
    //       { from: 0, to: 1000, name: "Small" },
    //       { from: 1001, to: 100000, name: "Medium" },
    //       { from: 100001, name: "Large" }
    //     ]
    //   },
    //   location: {
    //     // San Francisco. In the future, make this the user's current position
    //     center: "37.7749, -122.4194",
    //     type: "range",
    //     unit: "mi",
    //     ranges: [
    //       { from: 0, to: 100, name: "Nearby" },
    //       { from: 100, to: 500, name: "A longer drive" },
    //       { from: 500, name: "Perhaps fly?" }
    //     ]
    //   },
    //   date_established: {
    //     type: "range",
    //     ranges: [
    //       {
    //         from: moment().subtract(50, "years").toISOString(),
    //         name: "Within the last 50 years"
    //       },
    //       {
    //         from: moment().subtract(100, "years").toISOString(),
    //         to: moment().subtract(50, "years").toISOString(),
    //         name: "50 - 100 years ago"
    //       },
    //       {
    //         to: moment().subtract(100, "years").toISOString(),
    //         name: "More than 100 years ago"
    //       }
    //     ]
    //   },
    //   visitors: {
    //     type: "range",
    //     ranges: [
    //       { from: 0, to: 10000, name: "0 - 10000" },
    //       { from: 10001, to: 100000, name: "10001 - 100000" },
    //       { from: 100001, to: 500000, name: "100001 - 500000" },
    //       { from: 500001, to: 1000000, name: "500001 - 1000000" },
    //       { from: 1000001, to: 5000000, name: "1000001 - 5000000" },
    //       { from: 5000001, to: 10000000, name: "5000001 - 10000000" },
    //       { from: 10000001, name: "10000001+" }
    //     ]
    //   }
    // }
  },
  // autocompleteQuery: {
  //   results: {
  //     resultsPerPage: 5,
  //     result_fields: {
  //       title: {
  //         snippet: {
  //           size: 100,
  //           fallback: true
  //         }
  //       },
  //       nps_link: {
  //         raw: {}
  //       }
  //     }
  //   },
  //   suggestions: {
  //     types: {
  //       documents: {
  //         fields: ["title"]
  //       }
  //     },
  //     size: 4
  //   }
  // }
};

const SORT_OPTIONS = [
  {
    name: "Relevance",
    value: []
  },
  {
    name: "Title",
    value: [
      {
        field: "title",
        direction: "asc"
      }
    ]
  },
];

export default function App() {
  console.log(appConfig);
  return (
    <SearchProvider config={config}>
      <WithSearch
        mapContextToProps={({ wasSearched }) => ({
          wasSearched
        })}
      >
        {({ wasSearched }) => {
          return (
            <div className="App">
              <ErrorBoundary>
                <Layout
                  header={<SearchBox debounceLength={0} />}
                  sideContent={
                    <div>
                      {wasSearched && (
                        <Sorting label={"Sort by"} sortOptions={SORT_OPTIONS} />
                      )}
                      {/* Loop through appConfig.facets object and create Facet */}
                      {wasSearched && (
                        <React.Fragment>
                          {Object.keys(appConfig.facets).map((facet) => {
                            return (
                              <Facet
                                key={facet}
                                field={facet}
                                label={facet}
                                filterType="any"
                                isFilterable={true}
                              />
                            );
                          })}
                        </React.Fragment>
                      )}
                    </div>
                  }
                  bodyContent={
                    <Results
                      titleField="title"
                      urlField="nps_link"
                      thumbnailField="image_url"
                      shouldTrackClickThrough
                    />
                  }
                  bodyHeader={
                    <React.Fragment>
                      {wasSearched && <PagingInfo />}
                      {wasSearched && <ResultsPerPage />}
                    </React.Fragment>
                  }
                  bodyFooter={<Paging />}
                />
              </ErrorBoundary>
            </div>
          );
        }}
      </WithSearch>
    </SearchProvider>
  );
}
